// Minimum pane dimensions
export const MIN_PANE_WIDTH = 52;
export const MIN_PANE_HEIGHT = 11;
// Polling intervals
export const POLL_INTERVAL_MS = 2000;
export const SESSION_MISSING_GRACE_MS = 5000;
export const SESSION_TIMEOUT_MS = 10 * 60 * 1000;
//# sourceMappingURL=types.js.map