import type { PluginInput, PluginHooks } from './types';
export type { PluginInput, PluginHooks } from './types';
export type { AgentRole, AgentConfig, AgentContext, CoderTask, CoderConfig, McpConfig, TaskStatus, } from './types';
declare const Coder: (ctx: PluginInput) => Promise<PluginHooks>;
export default Coder;
//# sourceMappingURL=index.d.ts.map