export interface CloudContext {
    authenticated: boolean;
    orgId?: string;
    userId?: string;
}
export declare function getCloudContext(): Promise<CloudContext>;
export declare function checkAuth(): Promise<{
    ok: true;
    context: CloudContext;
} | {
    ok: false;
    error: string;
}>;
//# sourceMappingURL=auth.d.ts.map