interface ParsedFrontmatter<T = Record<string, unknown>> {
    data: T;
    body: string;
}
export declare function parseFrontmatter<T = Record<string, unknown>>(content: string): ParsedFrontmatter<T>;
export {};
//# sourceMappingURL=frontmatter.d.ts.map