import type { AgentRole } from '../types';
import type { AgentDefinition, AgentRegistry } from './types';
export type { AgentDefinition, AgentRegistry } from './types';
export declare const agents: Record<AgentRole, AgentDefinition>;
export declare function getAgent(role: AgentRole): AgentDefinition;
export declare function getAgentByRole(role: AgentRole): AgentDefinition | undefined;
export declare function getAgentById(id: string): AgentDefinition | undefined;
export declare function getAllAgents(): AgentDefinition[];
export declare function createAgentRegistry(): AgentRegistry;
//# sourceMappingURL=index.d.ts.map